==> barman_2.18.orig.tar.gz: barman-2.18/doc/manual/99-references.en.md <==
<!-- Reference links -->

  [rpo]: https://en.wikipedia.org/wiki/Recovery_point_objective
  [rto]: https://en.wikipedia.org/wiki/Recovery_time_objective
  [repmgr]: http://www.repmgr.org/
  [sqldump]: https://www.postgresql.org/docs/current/static/backup-dump.html
  [physicalbackup]: https://www.postgresql.org/docs/current/static/backup-file.html
  [pitr]: https://www.postgresql.org/docs/current/static/continuous-archiving.html
  [adminbook]: https://www.2ndquadrant.com/en/books/postgresql-10-administration-cookbook/
  [wal]: https://www.postgresql.org/docs/current/static/wal.html
  [49340627f9821e447f135455d942f7d5e96cae6d]: https://git.postgresql.org/gitweb/?p=postgresql.git;a=commit;h=49340627f9821e447f135455d942f7d5e96cae6d
  [requirements_recovery]: https://www.postgresql.org/docs/current/static/warm-standby.html#STANDBY-PLANNING
  [yumpgdg]: http://yum.postgresql.org/
  [aptpgdg]: http://apt.postgresql.org/
  [aptpgdgwiki]: https://wiki.postgresql.org/wiki/Apt
  [epel]: http://fedoraproject.org/wiki/EPEL
  [man5]: https://docs.pgbarman.org/barman.5.html
  [setup_user]: https://docs.python.org/3/install/index.html#alternate-installation-the-user-scheme
  [pypi]: https://pypi.python.org/pypi/barman/
  [pgpass]: https://www.postgresql.org/docs/current/static/libpq-pgpass.html
  [pghba]: http://www.postgresql.org/docs/current/static/client-authentication.html
  [authpghba]: http://www.postgresql.org/docs/current/static/auth-pg-hba-conf.html
  [streamprot]: http://www.postgresql.org/docs/current/static/protocol-replication.html
  [roles]: http://www.postgresql.org/docs/current/static/role-attributes.html
  [replication-slots]: https://www.postgresql.org/docs/current/static/warm-standby.html#STREAMING-REPLICATION-SLOTS
  [synch]: http://www.postgresql.org/docs/current/static/warm-standby.html#SYNCHRONOUS-REPLICATION
  [target]: https://www.postgresql.org/docs/current/static/recovery-target-settings.html
  [2ndqrpmrepo]: https://rpm.2ndquadrant.com/
  [2ndqdebrepo]: https://apt.2ndquadrant.com/
  [boto3]: https://github.com/boto/boto3
  [boto3creds]: https://boto3.amazonaws.com/v1/documentation/api/latest/guide/configuration.html
  [azure-identity]: https://docs.microsoft.com/en-us/python/api/azure-identity/?view=azure-python
  [azure-storage-blob]: https://docs.microsoft.com/en-us/python/api/azure-storage-blob/?view=azure-python
  [azure-storage-auth]: https://docs.microsoft.com/en-us/azure/storage/blobs/authorize-data-operations-cli#set-environment-variables-for-authorization-parameters


  [3]: http://github.com/EnterpriseDB/barman
  [8]: http://en.wikipedia.org/wiki/Hard_link
  [9]: https://github.com/2ndquadrant-it/pgespresso
  [11]: http://www.pgbarman.org/
  [12]: http://www.pgbarman.org/support/
  [13]: https://www.enterprisedb.com/
  [14]: http://www.pgbarman.org/faq/
  [15]: http://blog.2ndquadrant.com/tag/barman/
  [16]: https://github.com/hamann/check-barman
  [17]: https://github.com/2ndquadrant-it/puppet-barman
  [18]: http://4caast.morfeo-project.org/
  [20]: http://www.postgresql.org/docs/current/static/functions-admin.html
  [24]: http://www.postgresql.org/docs/current/static/warm-standby.html#STREAMING-REPLICATION
  [25]: http://www.postgresql.org/docs/current/static/app-pgreceivewal.html
  [26]: https://goo.gl/218Ghl
  [27]: https://github.com/emin100/barmanapi

  [31]: http://www.postgresql.org/

==> barman-2.19.tar.gz: barman-2.19/doc/manual/99-references.en.md <==
<!-- Reference links -->

  [rpo]: https://en.wikipedia.org/wiki/Recovery_point_objective
  [rto]: https://en.wikipedia.org/wiki/Recovery_time_objective
  [repmgr]: https://www.repmgr.org/
  [sqldump]: https://www.postgresql.org/docs/current/static/backup-dump.html
  [physicalbackup]: https://www.postgresql.org/docs/current/static/backup-file.html
  [pitr]: https://www.postgresql.org/docs/current/static/continuous-archiving.html
  [adminbook]: https://www.2ndquadrant.com/en/books/postgresql-10-administration-cookbook/
  [wal]: https://www.postgresql.org/docs/current/static/wal.html
  [49340627f9821e447f135455d942f7d5e96cae6d]: https://git.postgresql.org/gitweb/?p=postgresql.git;a=commit;h=49340627f9821e447f135455d942f7d5e96cae6d
  [requirements_recovery]: https://www.postgresql.org/docs/current/static/warm-standby.html#STANDBY-PLANNING
  [yumpgdg]: https://yum.postgresql.org/
  [aptpgdg]: https://apt.postgresql.org/
  [aptpgdgwiki]: https://wiki.postgresql.org/wiki/Apt
  [epel]: https://fedoraproject.org/wiki/EPEL
  [man5]: https://docs.pgbarman.org/barman.5.html
  [setup_user]: https://docs.python.org/3/install/index.html#alternate-installation-the-user-scheme
  [pypi]: https://pypi.python.org/pypi/barman/
  [pgpass]: https://www.postgresql.org/docs/current/static/libpq-pgpass.html
  [pghba]: https://www.postgresql.org/docs/current/static/client-authentication.html
  [authpghba]: https://www.postgresql.org/docs/current/static/auth-pg-hba-conf.html
  [streamprot]: https://www.postgresql.org/docs/current/static/protocol-replication.html
  [roles]: https://www.postgresql.org/docs/current/static/role-attributes.html
  [replication-slots]: https://www.postgresql.org/docs/current/static/warm-standby.html#STREAMING-REPLICATION-SLOTS
  [synch]: https://www.postgresql.org/docs/current/static/warm-standby.html#SYNCHRONOUS-REPLICATION
  [target]: https://www.postgresql.org/docs/current/static/runtime-config-wal.html#RUNTIME-CONFIG-WAL-RECOVERY-TARGET
  [2ndqrpmrepo]: https://rpm.2ndquadrant.com/
  [2ndqdebrepo]: https://apt.2ndquadrant.com/
  [boto3]: https://github.com/boto/boto3
  [boto3creds]: https://boto3.amazonaws.com/v1/documentation/api/latest/guide/configuration.html
  [azure-identity]: https://docs.microsoft.com/en-us/python/api/azure-identity/?view=azure-python
  [azure-storage-blob]: https://docs.microsoft.com/en-us/python/api/azure-storage-blob/?view=azure-python
  [azure-storage-auth]: https://docs.microsoft.com/en-us/azure/storage/blobs/authorize-data-operations-cli#set-environment-variables-for-authorization-parameters


  [3]: https://github.com/EnterpriseDB/barman
  [8]: https://en.wikipedia.org/wiki/Hard_link
  [9]: https://github.com/2ndquadrant-it/pgespresso
  [11]: https://www.pgbarman.org/
  [12]: https://www.pgbarman.org/support/
  [13]: https://www.enterprisedb.com/
  [14]: https://www.pgbarman.org/faq/
  [15]: https://blog.2ndquadrant.com/tag/barman/
  [16]: https://github.com/hamann/check-barman
  [17]: https://github.com/2ndquadrant-it/puppet-barman
  [18]: https://4caast.morfeo-project.org/
  [20]: https://www.postgresql.org/docs/current/static/functions-admin.html
  [24]: https://www.postgresql.org/docs/current/static/warm-standby.html#STREAMING-REPLICATION
  [25]: https://www.postgresql.org/docs/current/static/app-pgreceivewal.html
  [26]: https://goo.gl/218Ghl
  [27]: https://github.com/emin100/barmanapi

  [31]: https://www.postgresql.org/
